var config = {
    config: {
        mixins: {
            'Magento_Checkout/js/action/set-shipping-information': {
                'PortalPeople_ShippingFields/js/action/set-shipping-information-mixin': true
            },
            'Magento_Checkout/js/action/place-order': {
                'PortalPeople_ShippingFields/js/action/place-order-mixin': true
            },
            'Magento_Ui/js/form/element/date': {
                'PortalPeople_ShippingFields/js/form/element/date-disabled-weekdays-mixin': true
            },
            'Magento_Checkout/js/view/shipping': {
                'PortalPeople_ShippingFields/js/view/shipping-mixin': true
            }
        }
    }
};
